@@ -15,7 +15,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-version = '0.1.24'
+version = '0.1.25'
 release = 'barium'
 
 import os
@@ -34,6 +34,7 @@ from lettuce.decorators import step
 from lettuce.registry import call_hook
 from lettuce.registry import STEP_REGISTRY
 from lettuce.registry import CALLBACK_REGISTRY
+from lettuce.exceptions import StepLoadingError
 from lettuce.plugins import xunit_output
 
 from lettuce import exceptions
@@ -100,7 +101,11 @@ class Runner(object):
         features under `base_path` specified on constructor
         """
         started_at = datetime.now()
-        self.loader.find_and_load_step_definitions()
+        try:
+            self.loader.find_and_load_step_definitions()
+        except StepLoadingError, e:
+            print "Error loading step definitions:\n", e
+            return
 
         call_hook('before', 'all')
 
