@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # <Lettuce - Behaviour Driven Development for python>
-# Copyright (C) <2010>  Gabriel Falcão <gabriel@nacaolivre.org>
+# Copyright (C) <2010-2011>  Gabriel Falcão <gabriel@nacaolivre.org>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -79,4 +79,13 @@ LANGUAGES = {
         'scenario_outline': u'Plan de Scénario|Plan du Scénario',
         'scenario_separator': u'(Plan de Scénario|Plan du Scénario|Scénario)',
    },
+    'de': {
+        'examples': u'Beispiele|Szenarios',
+        'feature': u'Funktionalität|Funktion',
+        'name': u'German',
+        'native': u'Deutsch',
+        'scenario': u'Szenario',
+        'scenario_outline': u'Szenario-Zusammenfassung|Zusammenfassung',
+        'scenario_separator': u'(Szenario-Zusammenfassung|Zusammenfassung)',
+   },
 }
